Crate loco_keycloak_auth

Crate loco_keycloak_auth 

Modules

initializer
settings

Structs

Keycloak
Keycloak is a struct that holds the Keycloak authentication layer.
KeycloakToken
Token data parsed from the request and added as an axum::Extension through our middleware.

Functions

build_keycloak_layer
This function builds the Keycloak authentication layer using the settings from the application context.