Modules
Structs
- Keycloak
- Keycloak is a struct that holds the Keycloak authentication layer.
- Keycloak
Token - Token data parsed from the request and added as an
axum::Extensionthrough our middleware.
Functions
- build_
keycloak_ layer - This function builds the Keycloak authentication layer using the settings from the application context.